==> jc-1.4.0.tar.gz: javax/swing/JScrollBar__24AccessibleJScrollBar.h <==
// public class javax.swing.JScrollBar$AccessibleJScrollBar

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class d3ebb982a80b958b javax_swing_JScrollBar__24AccessibleJScrollBar

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JScrollBar__24AccessibleJScrollBar_H_
#define _JC_javax_swing_JScrollBar__24AccessibleJScrollBar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_accessibility_AccessibleValue$object;
struct _jc_javax_swing_JScrollBar$object;

// Typedefs
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object;

typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct;
typedef const struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods;
typedef const struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable;
typedef const struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype;

// Class fields structure
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$class_fields;

// Constructors
extern void _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$_init$ae957e7eb413d6c5(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *, struct _jc_javax_swing_JScrollBar$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
extern struct _jc_object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
extern jboolean _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *, struct _jc_java_lang_Number$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getAccessibleStateSet$1a4e9ea496bda550;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *);
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *, struct _jc_java_lang_Number$object *);
};

// Vtable
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods	javax_swing_JScrollBar__24AccessibleJScrollBar;
};

// Vtype
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype {
	_jc_type			type;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs {
	struct _jc_javax_swing_JScrollBar$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs {
    _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs	javax_swing_JScrollBar__24AccessibleJScrollBar;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs	javax_swing_JScrollBar__24AccessibleJScrollBar;
};

// Object instance structure
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object {
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype	*vtype;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JScrollBar__24AccessibleJScrollBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$class_object;

#endif	/* _JC_javax_swing_JScrollBar__24AccessibleJScrollBar_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JScrollBar__24AccessibleJScrollBar.h <==
// public class javax.swing.JScrollBar$AccessibleJScrollBar

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6d5f0a9d86bc5fc4 java_awt_Container__24AccessibleAWTContainer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext
// @dep_class 32f620e3c8c75689 javax_swing_JComponent__24AccessibleJComponent
// @dep_class d3ebb982a80b958b javax_swing_JScrollBar__24AccessibleJScrollBar

// header file dependencies
// @dep_header javax_swing_JComponent__24AccessibleJComponent

#include "javax/swing/JComponent__24AccessibleJComponent.h"

#ifndef _JC_javax_swing_JScrollBar__24AccessibleJScrollBar_H_
#define _JC_javax_swing_JScrollBar__24AccessibleJScrollBar_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_javax_accessibility_AccessibleRole$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;
struct _jc_javax_accessibility_AccessibleValue$object;
struct _jc_javax_swing_JScrollBar$object;

// Typedefs
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs;
typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object;

typedef struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct;
typedef const struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods;
typedef const struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable;
typedef const struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype;

// Class fields structure
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$fields_struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$class_fields;

// Constructors
extern void _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$_init$ae957e7eb413d6c5(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *, struct _jc_javax_swing_JScrollBar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleRole$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getAccessibleRole$eaa05a502d0ede18(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getAccessibleValue$ba7fc7ffdb66e551(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getCurrentAccessibleValue$c2e330a40c3d2acc(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getMaximumAccessibleValue$ec00d2a63914585e(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$getMinimumAccessibleValue$eeb09b9145034e84(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method$setCurrentAccessibleValue$0ceb1cadc12f10f4(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getAccessibleRole$eaa05a502d0ede18;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getAccessibleStateSet$1a4e9ea496bda550;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getAccessibleValue$ba7fc7ffdb66e551;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getCurrentAccessibleValue$c2e330a40c3d2acc;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getMaximumAccessibleValue$ec00d2a63914585e;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$getMinimumAccessibleValue$eeb09b9145034e84;
extern _jc_method _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$method_info$setCurrentAccessibleValue$0ceb1cadc12f10f4;

// Virtual methods structure
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods {
	struct _jc_javax_accessibility_AccessibleRole$object	*(*getAccessibleRole$eaa05a502d0ede18)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getAccessibleValue$ba7fc7ffdb66e551)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getCurrentAccessibleValue$c2e330a40c3d2acc)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMaximumAccessibleValue$ec00d2a63914585e)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Number$object	*(*getMinimumAccessibleValue$eeb09b9145034e84)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *) _JC_JCNI_ATTR;
	jboolean	(*setCurrentAccessibleValue$0ceb1cadc12f10f4)(_jc_env *, struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object *, struct _jc_java_lang_Number$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_Container__24AccessibleAWTContainer$vmethods	java_awt_Container__24AccessibleAWTContainer;
	_jc_javax_swing_JComponent__24AccessibleJComponent$vmethods	javax_swing_JComponent__24AccessibleJComponent;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vmethods	javax_swing_JScrollBar__24AccessibleJScrollBar;
};

// Vtype
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype {
	_jc_type			type;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs {
	struct _jc_javax_swing_JScrollBar$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs {
    _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_refs	javax_swing_JScrollBar__24AccessibleJScrollBar;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_refs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_refs	java_awt_Container__24AccessibleAWTContainer;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_Container__24AccessibleAWTContainer$sub_nonrefs	java_awt_Container__24AccessibleAWTContainer;
    _jc_javax_swing_JComponent__24AccessibleJComponent$sub_nonrefs	javax_swing_JComponent__24AccessibleJComponent;
    _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$sub_nonrefs	javax_swing_JScrollBar__24AccessibleJScrollBar;
};

// Object instance structure
struct _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$object {
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype	*vtype;
	_jc_javax_swing_JScrollBar__24AccessibleJScrollBar$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$vtype _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JScrollBar__24AccessibleJScrollBar, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JScrollBar__24AccessibleJScrollBar$class_object;

#endif	/* _JC_javax_swing_JScrollBar__24AccessibleJScrollBar_H_ */
